class XLSXFileMixin(object):
    """
    Mixin which allows the override of the filename being
    passed back to the user when the spreadsheet is downloaded.
    """

    def finalize_response(self, request, response, *args, **kwargs):
        response = super(XLSXFileMixin, self).finalize_response(request, response, *args, **kwargs)
        if response.accepted_renderer.format == 'xlsx':
            response['content-disposition'] = 'attachment; filename=export.xlsx'
        return response



from openpyxl import Workbook
from openpyxl.styles import Font
from openpyxl.utils import get_column_letter
from openpyxl.writer.excel import save_virtual_workbook
from rest_framework.renderers import BaseRenderer


class XLSXRenderer(BaseRenderer):
    """
    Renderer for Excel spreadsheet open data format (xlsx).
    """
    media_type = 'application/xlsx'
    format = 'xlsx'

    def render(self, data, accepted_media_type=None, renderer_context=None):
        """
        Render `data` into JSON, returning a bytestring.
        """
        row_count = 0

        if data is None:
            return bytes()

        wb = Workbook()

        ws = wb.active
        ws.title = 'Data Browser Export'

        for row in data['results']:
            # Reset the column count
            column_count = 0

            # Increase the row count
            row_count += 1

            # Set the header row
            if row_count == 1:
                for column_name in row.keys():
                    column_count += 1
                    ws.cell(
                        row=row_count,
                        column=column_count,
                        value='{}'.format(
                            column_name,
                        ),
                    )

                column_count = 0
                row_count += 1

            for column in row.items():
                column_count += 1
                ws.cell(
                    row=row_count,
                    column=column_count,
                    value='{}'.format(
                        column[1],
                    ),
                )

        for ws_column in range(1, column_count + 1):
            col_letter = get_column_letter(ws_column)
            ws.column_dimensions[col_letter].width = 15

        return save_virtual_workbook(wb)



from setuptools import setup, find_packages

setup(
    name='drf-renderer-xlsx',
    version="0.2.2",
    description='Django REST Framework renderer for spreadsheet (xlsx) files.',
    long_description='',
    author='Timothy Allen',
    author_email='tallen@wharton.upenn.edu',
    url='https://github.com/wharton/drf-renderer-xlsx',
    include_package_data=True,
    packages=find_packages(),
    zip_safe=False,
    install_requires=[
        'djangorestframework>=3.6',
        'openpyxl>=2.4',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Framework :: Django',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
